@@ -6,36 +6,41 @@ FLOAT = float
 
 class Run_Data(object):
     """
-    For use with python files.
-
-    Use this module to collect input arguments and other data about your file
-
-
-    Example:
-    `
     from essentials import run_data
+    import time
 
-    file_run_data = run_data.Run_Data()
+    file_run_data = run_data.Run_Data(__name__)
 
     #Collect input aruments from the command line
-    
+
     #  - Strings
-    mode = file_run_data.add_arg(run_data.Default_Arg('mode', default='easy', description="Mode game you would like. Options: easy normal hard"))
+    mode = file_run_data.add_arg(run_data.Default_Arg('mode', default='easy', description="Mode game you would like.", options=['easy', 'normal', 'hard']))
 
     #  - Integer
-    speed = file_run_data.add_arg(run_data.Default_Arg('speed', arg_type=run_data.INT, required=True, description="How fast you want the game to go."))
+    speed = file_run_data.add_arg(run_data.Default_Arg('speed', arg_type=run_data.INT, required=True, description="How fast you want the game to go. Example: 3"))
 
     #  - Float
     pixel_size = file_run_data.add_arg(run_data.Default_Arg('pixel_size', default=0.5, arg_type=run_data.FLOAT, description="What size you'd like the game to be"))
-    
+
+    #Print all config options
+    print("Mode:", mode, "\nSpeed:", speed, "\nSize:", pixel_size)
+
+    #Wait for the user defined speed
+    time.sleep(speed)
+
+    #Check if the file was ran in the main thread or the background - True or False bool value
+    if file_run_data.main_thread:
+        print("starting game")
+    else:
+        print("Just importing items.")
+
     #How long your file has been active
     print("You've been playing for:", file_run_data.up_time.seconds, "seconds")
-
     `
     """
     
 
-    def __init__(self):
+    def __init__(self, __name__):
         self.args = {}
         self.start_time = datetime.datetime.now()
         if __name__ == "__main__":
@@ -78,6 +83,11 @@ class Run_Data(object):
                 print("Use --" + arg.name + "=[VALUE]", "to set this argument\n")
                 if arg.description != "":
                     print(arg.name, "description:", arg.description)
+                if len(arg.options) > 0:
+                    print("Valid options for this argument include:")
+                    for item in arg.options:
+                        print(item)
+                    exit()
                 exit()
             else:
                 arg.value = arg.default
@@ -103,6 +113,7 @@ class Default_Arg(object):
         self.description = description
         self.type = arg_type
         self.value = default
+        self.options = options
         if arg_type == str:
             self.arg_type_string = "String"
         elif arg_type == int:
